import { TestBed } from '@angular/core/testing';
import { Router } from '@angular/router';
import { AuthGuard } from './auth.guard';
import { CookiesService } from './services/cookies/cookies.service';
import { ModalService } from './services/modal/modal.service';

describe('AuthGuard', () => {
  let guard: AuthGuard;
  let cookiesServiceSpy: jasmine.SpyObj<CookiesService>;
  let routerSpy: jasmine.SpyObj<Router>;
  let loginModalServiceSpy: jasmine.SpyObj<ModalService>;

  beforeEach(() => {
    cookiesServiceSpy = jasmine.createSpyObj('CookiesService', [
      'getToken',
    ]);
    routerSpy = jasmine.createSpyObj('Router', ['navigate']);
    loginModalServiceSpy = jasmine.createSpyObj('LoginModalService', [
      'openModal',
    ]);

    TestBed.configureTestingModule({
      providers: [
        AuthGuard,
        { provide: CookiesService, useValue: cookiesServiceSpy },
        { provide: Router, useValue: routerSpy },
        { provide: ModalService, useValue: loginModalServiceSpy },
      ],
    });

    guard = TestBed.inject(AuthGuard);
  });

  it('should allow activation when token exists', () => {
    cookiesServiceSpy.getToken.and.returnValue('valid-token');
    const result = guard.canActivate();
    expect(result).toBeTrue();
  });

  it('should deny activation and trigger redirect and modal when token is missing', async () => {
    cookiesServiceSpy.getToken.and.returnValue(null);
    routerSpy.navigate.and.returnValue(Promise.resolve(true));

    const result = guard.canActivate();
    expect(result).toBeFalse();
    expect(routerSpy.navigate).toHaveBeenCalledWith(['/']);
    expect(loginModalServiceSpy.openModal).toHaveBeenCalled();
  });
});
