import { Injectable } from '@angular/core';
import { environment } from '../../../environment';
import { HttpClient, HttpHeaders } from '@angular/common/http';
import { Observable } from 'rxjs';
import { AuthService } from '../auth/auth.service';

@Injectable({
  providedIn: 'root'
})
export class ImageService {
  private apiUrl = environment.apiURL;

  constructor(
    private http: HttpClient,
    private authService: AuthService
  ) { }

  getImage(imageId: string): Observable<Blob> {
    return this.http.get(`${this.apiUrl}/image/${imageId}`, { responseType: 'blob' });
  }

  postImage(image: File, date: string): Observable<any> {
    let url = `${this.apiUrl}/image/pin/null/add`;
    
    const formData = new FormData();
    formData.append('image', image);

    if(date !== '') {
      url += `?exif_date=${date}`;
    }

    return this.http.post(url, formData);
  }

  getImageMetadata(imageId: string): Observable<any> {
    return this.http.get(`${this.apiUrl}/image/${imageId}/metadata`);
  }
}